py_dss_interface package — py_dss_interface 1.0.1 documentation

# py_dss_interface package

## Submodules

## py_dss_interface.DSS module

class py_dss_interface.DSS.DSSDLL(dll_folder_param=None, dll_by_user=None)

  Bases: `py_dss_interface.models.ActiveClass.ActiveClass.ActiveClass`, `py_dss_interface.models.Bus.Bus.Bus`, `py_dss_interface.models.CapControls.CapControls.CapControls`, `py_dss_interface.models.Capacitors.Capacitors.Capacitors`, `py_dss_interface.models.Circuit.Circuit.Circuit`, `py_dss_interface.models.CktElement.CktElement.CktElement`, `py_dss_interface.models.CMathLib.CMathLib.CMathLib`, `py_dss_interface.models.CtrlQueue.CtrlQueue.CtrlQueue`, `py_dss_interface.models.DSSElement.DSSElement.DSSElement`, `py_dss_interface.models.DSSExecutive.DSSExecutive.DSSExecutive`, `py_dss_interface.models.DSSInterface.DSSInterface.DSSInterface`, `py_dss_interface.models.DSSProgress.DSSProgress.DSSProgress`, `py_dss_interface.models.DSSProperties.DSSProperties.DSSProperties`, `py_dss_interface.models.ErrorInterface.ErrorInterface.ErrorOpenDSS`, `py_dss_interface.models.Fuses.Fuses.Fuses`, `py_dss_interface.models.Generators.Generators.Generators`, `py_dss_interface.models.Lines.Lines.Lines`, `py_dss_interface.models.Loads.Loads.Loads`, `py_dss_interface.models.ISources.ISources.ISources`, `py_dss_interface.models.LineCodes.LineCodes.LineCodes`, `py_dss_interface.models.LoadShapes.LoadShapes.LoadShapes`, `py_dss_interface.models.Meters.Meters.Meters`, `py_dss_interface.models.Monitors.Monitors.Monitors`, `py_dss_interface.models.Parallel.Parallel.Parallel`, `py_dss_interface.models.Parser.Parser.Parser`, `py_dss_interface.models.PVSystems.PVSystems.PVSystems`, `py_dss_interface.models.Sensors.Sensors.Sensors`, `py_dss_interface.models.Solution.Solution.Solution`, `py_dss_interface.models.Text.Text.Text`, `py_dss_interface.models.Topology.Topology.Topology`, `py_dss_interface.models.Transformers.Transformers.Transformers`, `py_dss_interface.models.VSources.VSources.VSources`, `py_dss_interface.models.XYCurves.XYCurves.XYCurves`

  check_started()
  class_commands = []
  dll_folder: str
  dll_path: str
  dss_obj: <ctypes.LibraryLoader object at 0x000001CC1AE3F308>
  load_json()
  memory_commands = []
  my_dss_version: ctypes.c_char_p
  started = False

## Module contents